#                             AlloppDT.

# Started 2013-02-03. 
# This is for the network model with an arbitrary number
# of diploids (>=2), tetraploids (>=1) and hybridizations. 
# This is the post-BEAST computations: Tree Annotator
# and making PDFs. The separation allows differebt burnins, etc.

# Details are read from config file so care needed to ensure match of
# GNT, chain length  (latter used to calc burnin).

# It shares code with AlloppDT_main.r
# This should be re-organized to minimise sharing




library(ape)

################################################################################
###################### Setting up file paths, loading code #####################

cat("AlloppDT started\n")
#Args <- commandArgs(TRUE)
Args <- c("VOSTROWIN7", "C:/Users/Graham/AAA/Programming/GoteborgSim/2013-05-03/J")
stopifnot(length(Args) == 2)

setwd("C:/Users/Graham/AAA/Programming/Goteborg/AlloppRcode-nhybs")

# Sets variables computer, config.dir, java.classpath, seqgenbasecmd
source("AlloppDT_0filepaths.r")

# Code providing functions
source("AlloppDT_0randomseeds.r")
source("AlloppDT_1readconfig.r")
source("AlloppDT_2makemultree.r")
source("AlloppDT_3makegtrees.r")
source("AlloppDT_4makeseqfiles.r")
source("AlloppDT_5beastxml_toplevel.r")
source("AlloppDT_6beastxml_bits.r")
source("AlloppDT_7utils.r")

################################################################################
######################### Top level functions ##################################
  
run.treeannotator.on.gtrees.one.GNT.one.rep <- function(config, i, r, gtree.burnin) {
  for (g in 1:config$configG[i]) {
    TreeAnnotator.cmd <-paste("java -classpath", java.classpath, 
          "dr.app.tools.TreeAnnotator -burnin", gtree.burnin, 
          fpath.sampledgtree(config, i, r, g),
          fpath.mccgtree(config, i, r, g)
          )
    system(TreeAnnotator.cmd)
    }
  }


run.treeannotator.on.multree.one.GNT.one.rep <- function(config, i, r, multree.burnin) {
  TreeAnnotator.cmd <-paste("java -classpath", java.classpath, 
          "dr.app.tools.TreeAnnotator -burnin", multree.burnin,
          fpath.sampledmultrees(config, i, r),
          fpath.mccmultree(config, i, r)
          )      
   system(TreeAnnotator.cmd)
  }  
  

run.treeannotator.for.one.GNT.one.replicate <- function(config, i, r, gtree.burnin, multree.burnin) {
  run.treeannotator.on.gtrees.one.GNT.one.rep(config, i, r, gtree.burnin) 
  run.treeannotator.on.multree.one.GNT.one.rep(config, i, r, multree.burnin)
  }  
  
  
convert.concensus.gtrees.to.pdf <- function(config, i, r) {
  for (g in 1:config$configG[i]) {
    pdf(file=fpath.mccgtree.pdf(config, i, r, g))
    plot.tree.from.nexus.file(fpath.mccgtree(config, i, r, g), branchcolour="brown")
    title(paste("Concensus gene tree: rep", r, "gene", g))
    dev.off()
    }
  }

convert.concensus.multree.to.pdf <- function(config, i, r) {
  pdf(file=fpath.mccmultree.pdf(config, i, r))
  plot.tree.from.nexus.file(fpath.mccmultree(config, i, r), branchcolour="red")
  title(paste("Concensus MUL-tree: rep", r))
  dev.off()    
  }    
  

convert.concensustrees.to.pdf <- function(config, i, r) {
  convert.concensus.gtrees.to.pdf(config, i, r)
  convert.concensus.multree.to.pdf(config, i, r)   
  }  
    
    
    
  
################################################################################
########################## Business starts here ################################


cat("AlloppDT running with directory", config.dir, "\n")

config <- read.config(config.dir)

cat("Config has beeen read\n")

nofGNT <- length(config$configG)
beast.randomseed <- config$progparams$beastseed
beast.chain.length <- config$progparams$beastchainlength
beast.screen.logevery <- config$progparams$beastscreen.logevery
beast.params.logevery <- config$progparams$beastparams.logevery
beast.gtrees.logevery <- config$progparams$beastgtrees.logevery
beast.multree.logevery <- config$progparams$beastmultree.logevery
beast.dbugtune.logevery <- config$progparams$beastdbugtune.logevery
treeann.burnin <- config$progparams$treeannburnin

# Often need to edit this!
gtree.burnin <- (beast.chain.length - 2*1000*1000) / beast.gtrees.logevery
multree.burnin <- (beast.chain.length - 2*1000*1000) / beast.multree.logevery

replicate.sets <- NULL
for (i in 1:nofGNT) {
  R <- config$configR[i]
  replicate.sets <- c(replicate.sets, list(1:R))
  }




for (i in 1:nofGNT) {
  for (r in replicate.sets[[i]]) {
    run.treeannotator.for.one.GNT.one.replicate(config, i, r, gtree.burnin, multree.burnin)
    }
  }
  
  
for (i in 1:nofGNT) {
  for (r in replicate.sets[[i]]) {
    convert.concensustrees.to.pdf(config, i, r)
    }
  }



